summaryrefslogtreecommitdiff
path: root/gdk/gdkdraw.c
diff options
context:
space:
mode:
authorBenjamin Otte <otte@redhat.com>2010-06-28 14:44:12 +0200
committerBenjamin Otte <otte@redhat.com>2010-06-29 16:06:38 +0200
commit3e96cfe8fcfeedabc09b2a8b3aa87007a3b5a2a0 (patch)
treea5b8a39ad674b77e2d1beeb234c0cdd48d218b20 /gdk/gdkdraw.c
parent52200eee01cc055adaefb678d6c6f04455d1a593 (diff)
downloadgtk+-3e96cfe8fcfeedabc09b2a8b3aa87007a3b5a2a0.tar.gz
Deprecate the GdkRegion API
Includes fixing all callers to use the cairo region API instead. This is usually just replacing the function names, the only difference is gdk_region_get_rectangles() being replaced by cairo_region_num_rectangles() and cairo_region_get_rectangle() which required a bit more work. https://bugzilla.gnome.org/show_bug.cgi?id=613284
Diffstat (limited to 'gdk/gdkdraw.c')
-rw-r--r--gdk/gdkdraw.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/gdk/gdkdraw.c b/gdk/gdkdraw.c
index 47a2a7d99a..6ea712d91c 100644
--- a/gdk/gdkdraw.c
+++ b/gdk/gdkdraw.c
@@ -1059,7 +1059,7 @@ gdk_drawable_real_get_composite_drawable (GdkDrawable *drawable,
* but no area outside of this region will be affected by drawing
* primitives.
*
* Returns: a #GdkRegion. This must be freed with gdk_region_destroy()
* when you are done.
**/
GdkRegion *
@@ -1079,7 +1079,7 @@ gdk_drawable_get_clip_region (GdkDrawable *drawable)
* obscured by other windows, but no area outside of this region
* is visible.
*
* Returns: a #GdkRegion. This must be freed with gdk_region_destroy()
* when you are done.
**/
GdkRegion *
@@ -1100,7 +1100,7 @@ gdk_drawable_real_get_visible_region (GdkDrawable *drawable)
gdk_drawable_get_size (drawable, &rect.width, &rect.height);
- return gdk_region_rectangle (&rect);
+ return cairo_region_create_rectangle (&rect);
}
/**
@@ -1431,15 +1431,15 @@ gdk_drawable_real_draw_pixbuf (GdkDrawable *drawable,
tmp_rect.width = width;
tmp_rect.height = height;
- drect = gdk_region_rectangle (&tmp_rect);
+ drect = cairo_region_create_rectangle (&tmp_rect);
clip = gdk_drawable_get_clip_region (drawable);
- gdk_region_intersect (drect, clip);
+ cairo_region_intersect (drect, clip);
- gdk_region_get_clipbox (drect, &tmp_rect);
+ cairo_region_get_extents (drect, &tmp_rect);
- gdk_region_destroy (drect);
- gdk_region_destroy (clip);
+ cairo_region_destroy (drect);
+ cairo_region_destroy (clip);
if (tmp_rect.width == 0 ||
tmp_rect.height == 0)
@@ -1059,7 +1059,7 @@ gdk_drawable_real_get_composite_drawable (GdkDrawable *drawable,
* primitives.
*
- * Returns: a #GdkRegion. This must be freed with gdk_region_destroy()
+ * Returns: a #GdkRegion. This must be freed with cairo_region_destroy()
* when you are done.
**/
@@ -1079,7 +1079,7 @@ gdk_drawable_get_clip_region (GdkDrawable *drawable)
* is visible.
*
- * Returns: a #GdkRegion. This must be freed with gdk_region_destroy()
+ * Returns: a #GdkRegion. This must be freed with cairo_region_destroy()
* when you are done.
**/